You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ch...@apache.org on 2014/09/12 20:23:34 UTC

svn commit: r1624604 [3/3] - in /qpid/trunk/qpid/cpp: ./ bindings/ bindings/qpid/dotnet/ bindings/qpid/dotnet/examples/msvc10/csharp.direct.receiver/ bindings/qpid/dotnet/examples/msvc10/csharp.direct.sender/ bindings/qpid/dotnet/examples/msvc10/csharp...

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc9/org.apache.qpid.messaging.sessionreceiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc9/org.apache.qpid.messaging.sessionreceiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc9/org.apache.qpid.messaging.sessionreceiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc9/org.apache.qpid.messaging.sessionreceiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc9/org.apache.qpid.messaging.sessionreceiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc9/org.apache.qpid.messaging.sessionreceiver.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc9/org.apache.qpid.messaging.sessionreceiver.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,16 +28,16 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>org.apache.qpid.messaging.sessionreceiver</RootNamespace>
     <AssemblyName>org.apache.qpid.messaging.sessionreceiver</AssemblyName>
-    <TargetFrameworkVersion>v2.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <SignAssembly>true</SignAssembly>
-    <AssemblyOriginatorKeyFile>..\qpid.snk</AssemblyOriginatorKeyFile>
+    <AssemblyOriginatorKeyFile>${CMAKE_CURRENT_SOURCE_DIR}/src/qpid.snk</AssemblyOriginatorKeyFile>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|AnyCPU' ">
     <DebugSymbols>true</DebugSymbols>
     <DebugType>full</DebugType>
     <Optimize>false</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
@@ -45,21 +45,21 @@ under the License.
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|AnyCPU' ">
     <DebugType>pdbonly</DebugType>
     <Optimize>true</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x86' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x86</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x86' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -68,14 +68,14 @@ under the License.
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x64' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x64</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x64' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -83,7 +83,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|AnyCPU' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -91,7 +91,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|x86' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -99,7 +99,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|x64' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -110,17 +110,17 @@ under the License.
     <Reference Include="System" />
   </ItemGroup>
   <ItemGroup>
-    <Compile Include="..\sessionreceiver.cs" />
-    <Compile Include="$(QPID_BUILD_ROOT)\src\windows\generated_src\sessionreceiver-AssemblyInfo.cs" />
+    <Compile Include="${CMAKE_CURRENT_SOURCE_DIR}/src/sessionreceiver/sessionreceiver.cs" />
+    <Compile Include="${PROJECT_BINARY_DIR}/src/windows/generated_src/sessionreceiver-AssemblyInfo.cs" />
   </ItemGroup>
   <ItemGroup>
-    <ProjectReference Include="..\..\msvc9\org.apache.qpid.messaging.vcproj">
+    <ProjectReference Include="../${DOTNET_exampleRelPathToBindingProj}">
       <Project>{AA5A3B83-5F98-406D-A01C-5A921467A57D}</Project>
       <Name>Org.Apache.Qpid.Messaging</Name>
     </ProjectReference>
   </ItemGroup>
   <ItemGroup>
-    <None Include="..\qpid.snk" />
+    <None Include="${CMAKE_CURRENT_SOURCE_DIR}/src/qpid.snk" />
   </ItemGroup>
   <Import Project="$(MSBuildToolsPath)\Microsoft.CSharp.targets" />
   <!-- To modify your build process, add your task inside one of the targets below and uncomment it. 

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvcx/org.apache.qpid.messaging.sessionreceiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc10/org.apache.qpid.messaging.sessionreceiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvcx/org.apache.qpid.messaging.sessionreceiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvcx/org.apache.qpid.messaging.sessionreceiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc10/org.apache.qpid.messaging.sessionreceiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvc10/org.apache.qpid.messaging.sessionreceiver.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/src/sessionreceiver/msvcx/org.apache.qpid.messaging.sessionreceiver.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,10 +28,10 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>org.apache.qpid.messaging.sessionreceiver</RootNamespace>
     <AssemblyName>org.apache.qpid.messaging.sessionreceiver</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <SignAssembly>true</SignAssembly>
-    <AssemblyOriginatorKeyFile>$(ProjectDir)..\qpid.snk</AssemblyOriginatorKeyFile>
+    <AssemblyOriginatorKeyFile>${DOTNET_currentSourceDir}\src\qpid.snk</AssemblyOriginatorKeyFile>
     <FileUpgradeFlags>
     </FileUpgradeFlags>
     <OldToolsVersion>3.5</OldToolsVersion>
@@ -42,7 +42,7 @@ under the License.
     <DebugSymbols>true</DebugSymbols>
     <DebugType>full</DebugType>
     <Optimize>false</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
@@ -50,21 +50,21 @@ under the License.
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|AnyCPU' ">
     <DebugType>pdbonly</DebugType>
     <Optimize>true</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x86' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x86</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x86' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -73,14 +73,14 @@ under the License.
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x64' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x64</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x64' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -88,7 +88,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|AnyCPU' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -96,7 +96,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|x86' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -104,7 +104,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|x64' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -115,17 +115,23 @@ under the License.
     <Reference Include="System" />
   </ItemGroup>
   <ItemGroup>
-    <Compile Include="..\sessionreceiver.cs" />
-    <Compile Include="$(QPID_BUILD_ROOT)\src\windows\generated_src\sessionreceiver-AssemblyInfo.cs" />
+    <Compile Include="..\..\..\${DOTNET_relPathToSrc}\src\sessionreceiver\sessionreceiver.cs">
+        <Link>sessionreceiver.cs</Link>
+    </Compile>
+    <Compile Include="${DOTNET_projectBinaryDir}\src\windows\generated_src\sessionreceiver-AssemblyInfo.cs">
+        <Link>sessionreceiver-AssemblyInfo.cs</Link>
+    </Compile>
   </ItemGroup>
   <ItemGroup>
-    <ProjectReference Include="..\..\msvc10\org.apache.qpid.messaging.vcxproj">
+    <ProjectReference Include="..\${DOTNET_exampleRelPathToBindingProj}">
       <Project>{AA5A3B83-5F98-406D-A01C-5A921467A57D}</Project>
       <Name>Org.Apache.Qpid.Messaging</Name>
     </ProjectReference>
   </ItemGroup>
   <ItemGroup>
-    <None Include="$(ProjectDir)..\qpid.snk" />
+    <None Include="..\..\..\${DOTNET_relPathToSrc}\src\qpid.snk">
+        <Link>qpid.snk</Link>
+    </None>
   </ItemGroup>
   <Import Project="$(MSBuildToolsPath)\Microsoft.CSharp.targets" />
   <!-- To modify your build process, add your task inside one of the targets below and uncomment it. 

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc9/messaging.test.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc9/messaging.test.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc9/messaging.test.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc9/messaging.test.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc9/messaging.test.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc9/messaging.test.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc9/messaging.test.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>messaging.test</RootNamespace>
     <AssemblyName>messaging.test</AssemblyName>
-    <TargetFrameworkVersion>v3.5</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <StartupObject>
     </StartupObject>
@@ -52,7 +52,7 @@ under the License.
     <DebugSymbols>true</DebugSymbols>
     <DebugType>full</DebugType>
     <Optimize>false</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
@@ -60,21 +60,21 @@ under the License.
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|AnyCPU' ">
     <DebugType>pdbonly</DebugType>
     <Optimize>true</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x86' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x86</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x86' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -83,14 +83,14 @@ under the License.
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x64' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x64</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x64' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}\src\$(Configuration)\</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -128,12 +128,12 @@ under the License.
     </Reference>
   </ItemGroup>
   <ItemGroup>
-    <Compile Include="..\messaging.test.address.cs" />
-    <Compile Include="..\messaging.test.connection.cs" />
-    <Compile Include="..\messaging.test.cs" />
-    <Compile Include="..\messaging.test.duration.cs" />
-    <Compile Include="..\messaging.test.message.cs" />
-    <Compile Include="..\Properties\AssemblyInfo.cs" />
+    <Compile Include="${CMAKE_CURRENT_SOURCE_DIR}/test/messaging.test/messaging.test.address.cs" />
+    <Compile Include="${CMAKE_CURRENT_SOURCE_DIR}/test/messaging.test/messaging.test.connection.cs" />
+    <Compile Include="${CMAKE_CURRENT_SOURCE_DIR}/test/messaging.test/messaging.test.cs" />
+    <Compile Include="${CMAKE_CURRENT_SOURCE_DIR}/test/messaging.test/messaging.test.duration.cs" />
+    <Compile Include="${CMAKE_CURRENT_SOURCE_DIR}/test/messaging.test/messaging.test.message.cs" />
+    <Compile Include="${CMAKE_CURRENT_SOURCE_DIR}/test/messaging.test/Properties\AssemblyInfo.cs" />
   </ItemGroup>
   <ItemGroup>
     <BootstrapperPackage Include="Microsoft.Net.Framework.2.0">
@@ -158,7 +158,7 @@ under the License.
     </BootstrapperPackage>
   </ItemGroup>
   <ItemGroup>
-    <ProjectReference Include="..\..\..\src\msvc9\org.apache.qpid.messaging.vcproj">
+    <ProjectReference Include="${DOTNET_exampleRelPathToBindingProj}">
       <Project>{AA5A3B83-5F98-406D-A01C-5A921467A57D}</Project>
       <Name>Org.Apache.Qpid.Messaging</Name>
     </ProjectReference>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvcx/messaging.test.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc10/messaging.test.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvcx/messaging.test.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvcx/messaging.test.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc10/messaging.test.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvc10/messaging.test.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/test/messaging.test/msvcx/messaging.test.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>messaging.test</RootNamespace>
     <AssemblyName>messaging.test</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <StartupObject>
     </StartupObject>
@@ -57,7 +57,7 @@ under the License.
     <DebugSymbols>true</DebugSymbols>
     <DebugType>full</DebugType>
     <Optimize>false</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
@@ -65,21 +65,21 @@ under the License.
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|AnyCPU' ">
     <DebugType>pdbonly</DebugType>
     <Optimize>true</Optimize>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <ErrorReport>prompt</ErrorReport>
     <WarningLevel>4</WarningLevel>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x86' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x86</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x86' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -88,14 +88,14 @@ under the License.
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Debug|x64' ">
     <DebugSymbols>true</DebugSymbols>
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>DEBUG;TRACE</DefineConstants>
     <DebugType>full</DebugType>
     <PlatformTarget>x64</PlatformTarget>
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'Release|x64' ">
-    <OutputPath>$(QPID_BUILD_ROOT)\src\$(Configuration)\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -103,7 +103,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|AnyCPU' ">
-    <OutputPath>bin\RelWithDebInfo\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -111,7 +111,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|x86' ">
-    <OutputPath>bin\x86\RelWithDebInfo\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -119,7 +119,7 @@ under the License.
     <ErrorReport>prompt</ErrorReport>
   </PropertyGroup>
   <PropertyGroup Condition=" '$(Configuration)|$(Platform)' == 'RelWithDebInfo|x64' ">
-    <OutputPath>bin\x64\RelWithDebInfo\</OutputPath>
+    <OutputPath>${PROJECT_BINARY_DIR}/src/$(Configuration)/</OutputPath>
     <DefineConstants>TRACE</DefineConstants>
     <Optimize>true</Optimize>
     <DebugType>pdbonly</DebugType>
@@ -133,12 +133,24 @@ under the License.
     </Reference>
   </ItemGroup>
   <ItemGroup>
-    <Compile Include="..\messaging.test.address.cs" />
-    <Compile Include="..\messaging.test.connection.cs" />
-    <Compile Include="..\messaging.test.cs" />
-    <Compile Include="..\messaging.test.duration.cs" />
-    <Compile Include="..\messaging.test.message.cs" />
-    <Compile Include="..\Properties\AssemblyInfo.cs" />
+    <Compile Include="..\..\..\${DOTNET_relPathToSrc}\test\messaging.test\messaging.test.address.cs">
+      <Link>messaging.test.address.cs</Link>
+    </Compile>
+    <Compile Include="..\..\..\${DOTNET_relPathToSrc}\test\messaging.test\messaging.test.connection.cs">
+      <Link>messaging.test.connection.cs</Link>
+    </Compile>
+    <Compile Include="..\..\..\${DOTNET_relPathToSrc}\test\messaging.test\messaging.test.cs">
+      <Link>messaging.test.cs</Link>
+    </Compile>
+    <Compile Include="..\..\..\${DOTNET_relPathToSrc}\test\messaging.test\messaging.test.duration.cs">
+      <Link>messaging.test.duration.cs</Link>
+    </Compile>
+    <Compile Include="..\..\..\${DOTNET_relPathToSrc}\test\messaging.test\messaging.test.message.cs">
+      <Link>messaging.test.message.cs</Link>
+    </Compile>
+    <Compile Include="..\..\..\${DOTNET_relPathToSrc}\test\messaging.test\Properties\AssemblyInfo.cs">
+      <Link>AssemblyInfo.cs</Link>
+    </Compile>
   </ItemGroup>
   <ItemGroup>
     <BootstrapperPackage Include="Microsoft.Net.Framework.2.0">
@@ -163,7 +175,7 @@ under the License.
     </BootstrapperPackage>
   </ItemGroup>
   <ItemGroup>
-    <ProjectReference Include="..\..\..\src\msvc10\org.apache.qpid.messaging.vcxproj">
+    <ProjectReference Include="${DOTNET_exampleRelPathToBindingProj}">
       <Project>{AA5A3B83-5F98-406D-A01C-5A921467A57D}</Project>
       <Name>Org.Apache.Qpid.Messaging</Name>
     </ProjectReference>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.receiver/csharp.direct.receiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.receiver/csharp.direct.receiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.receiver/csharp.direct.receiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.receiver/csharp.direct.receiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.receiver/csharp.direct.receiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.sender/csharp.direct.sender.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.sender/csharp.direct.sender.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.sender/csharp.direct.sender.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.sender/csharp.direct.sender.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.direct.sender/csharp.direct.sender.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.client/csharp.example.client.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.client/csharp.example.client.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.client/csharp.example.client.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.client/csharp.example.client.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.client/csharp.example.client.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.drain/csharp.example.drain.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.drain/csharp.example.drain.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.drain/csharp.example.drain.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.drain/csharp.example.drain.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.drain/csharp.example.drain.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.helloworld/csharp.example.helloworld.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.helloworld/csharp.example.helloworld.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.helloworld/csharp.example.helloworld.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.helloworld/csharp.example.helloworld.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.helloworld/csharp.example.helloworld.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.server/csharp.example.server.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.server/csharp.example.server.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.server/csharp.example.server.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.server/csharp.example.server.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.server/csharp.example.server.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.spout/csharp.example.spout.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.spout/csharp.example.spout.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.spout/csharp.example.spout.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.spout/csharp.example.spout.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.example.spout/csharp.example.spout.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.receiver/csharp.map.receiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.receiver/csharp.map.receiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.receiver/csharp.map.receiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.receiver/csharp.map.receiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.receiver/csharp.map.receiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.sender/csharp.map.sender.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.sender/csharp.map.sender.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.sender/csharp.map.sender.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.sender/csharp.map.sender.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/examples/csharp.map.sender/csharp.map.sender.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/winsdk_dotnet_examples.sln.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/winsdk_dotnet_examples.sln)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/winsdk_dotnet_examples.sln.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/winsdk_dotnet_examples.sln.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc9/winsdk_dotnet_examples.sln&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
    (empty)

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.receiver/csharp.direct.receiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.direct.receiver/csharp.direct.receiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.receiver/csharp.direct.receiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.receiver/csharp.direct.receiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.direct.receiver/csharp.direct.receiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.direct.receiver/csharp.direct.receiver.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.receiver/csharp.direct.receiver.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.direct.receiver</RootNamespace>
     <AssemblyName>csharp.direct.receiver</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.sender/csharp.direct.sender.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.direct.sender/csharp.direct.sender.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.sender/csharp.direct.sender.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.sender/csharp.direct.sender.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.direct.sender/csharp.direct.sender.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.direct.sender/csharp.direct.sender.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.direct.sender/csharp.direct.sender.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.direct.sender</RootNamespace>
     <AssemblyName>csharp.direct.sender</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.client/csharp.example.client.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.client/csharp.example.client.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.client/csharp.example.client.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.client/csharp.example.client.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.client/csharp.example.client.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.client/csharp.example.client.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.client/csharp.example.client.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.example.client</RootNamespace>
     <AssemblyName>csharp.example.client</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.declare_queues/csharp.example.declare_queues.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.example.declare_queues</RootNamespace>
     <AssemblyName>csharp.example.declare_queues</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.drain/csharp.example.drain.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.drain/csharp.example.drain.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.drain/csharp.example.drain.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.drain/csharp.example.drain.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.drain/csharp.example.drain.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.drain/csharp.example.drain.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.drain/csharp.example.drain.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.example.drain</RootNamespace>
     <AssemblyName>csharp.example.drain</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.helloworld/csharp.example.helloworld.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.helloworld/csharp.example.helloworld.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.helloworld/csharp.example.helloworld.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.helloworld/csharp.example.helloworld.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.helloworld/csharp.example.helloworld.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.helloworld/csharp.example.helloworld.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.helloworld/csharp.example.helloworld.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.example.helloworld</RootNamespace>
     <AssemblyName>csharp.example.helloworld</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.server/csharp.example.server.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.server/csharp.example.server.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.server/csharp.example.server.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.server/csharp.example.server.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.server/csharp.example.server.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.server/csharp.example.server.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.server/csharp.example.server.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.example.server</RootNamespace>
     <AssemblyName>csharp.example.server</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.spout/csharp.example.spout.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.spout/csharp.example.spout.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.spout/csharp.example.spout.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.spout/csharp.example.spout.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.spout/csharp.example.spout.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.example.spout/csharp.example.spout.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.example.spout/csharp.example.spout.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.example.spout</RootNamespace>
     <AssemblyName>csharp.example.spout</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.receiver/csharp.map.callback.receiver.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.map.callback.receiver</RootNamespace>
     <AssemblyName>csharp.map.callback.receiver</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.callback.sender/csharp.map.callback.sender.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.map.callback.sender</RootNamespace>
     <AssemblyName>csharp.map.callback.sender</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.receiver/csharp.map.receiver.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.receiver/csharp.map.receiver.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.receiver/csharp.map.receiver.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.receiver/csharp.map.receiver.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.receiver/csharp.map.receiver.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.receiver/csharp.map.receiver.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.receiver/csharp.map.receiver.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.map.receiver</RootNamespace>
     <AssemblyName>csharp.map.receiver</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.sender/csharp.map.sender.csproj.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.sender/csharp.map.sender.csproj)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.sender/csharp.map.sender.csproj.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.sender/csharp.map.sender.csproj.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.sender/csharp.map.sender.csproj&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/examples/csharp.map.sender/csharp.map.sender.csproj (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/examples/csharp.map.sender/csharp.map.sender.csproj.in Fri Sep 12 18:23:31 2014
@@ -28,7 +28,7 @@ under the License.
     <AppDesignerFolder>Properties</AppDesignerFolder>
     <RootNamespace>csharp.map.sender</RootNamespace>
     <AssemblyName>csharp.map.sender</AssemblyName>
-    <TargetFrameworkVersion>v4.0</TargetFrameworkVersion>
+    <TargetFrameworkVersion>${DOTNET_TARGET_FRAMEWORK_VERSION}</TargetFrameworkVersion>
     <FileAlignment>512</FileAlignment>
     <FileUpgradeFlags>
     </FileUpgradeFlags>

Copied: qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/winsdk_dotnet_examples.sln.in (from r1624570, qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/winsdk_dotnet_examples.sln)
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/winsdk_dotnet_examples.sln.in?p2=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/winsdk_dotnet_examples.sln.in&p1=qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/winsdk_dotnet_examples.sln&r1=1624570&r2=1624604&rev=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvc10/winsdk_dotnet_examples.sln (original)
+++ qpid/trunk/qpid/cpp/bindings/qpid/dotnet/winsdk_sources/msvcx/winsdk_dotnet_examples.sln.in Fri Sep 12 18:23:31 2014
@@ -1,5 +1,5 @@
-Microsoft Visual Studio Solution File, Format Version 11.00
-# Visual Studio 2010
+Microsoft Visual Studio Solution File, Format Version ${DOTNET_SLN_FILE_FORMAT}
+# ${DOTNET_SLN_VISUAL_STUDIO}
 
 # 
 # Licensed to the Apache Software Foundation (ASF) under one

Modified: qpid/trunk/qpid/cpp/bld-winsdk.ps1
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/bld-winsdk.ps1?rev=1624604&r1=1624603&r2=1624604&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/bld-winsdk.ps1 (original)
+++ qpid/trunk/qpid/cpp/bld-winsdk.ps1 Fri Sep 12 18:23:31 2014
@@ -22,9 +22,15 @@
 # It builds a single SDK.zip file.
 # The environment for the build has been set up externally so
 # that 'devenv' runs the right version of Visual Studio (2008
-# or 2010) and the right architecture (x86 or x64), typically:
-# C:\Program Files (x86)\Microsoft Visual Studio 10.0\VC\bin\vcvars32.bat or
-# C:\Program Files (x86)\Microsoft Visual Studio 10.0\VC\bin\amd64\vcvarsamd64.bat
+# 2010 2012) and the right architecture (x86 or x64), typically:
+#    call "%VS90COMNTOOLS%..\..\VC\vcvarsall.bat" x86
+#    call "%VS90COMNTOOLS%..\..\VC\vcvarsall.bat" amd64
+# or
+#    call "%VS100COMNTOOLS%..\..\VC\vcvarsall.bat" x86
+#    call "%VS100COMNTOOLS%..\..\VC\vcvarsall.bat" amd64
+# or
+#    call "%VS110COMNTOOLS%..\..\VC\vcvarsall.bat" x86
+#    call "%VS110COMNTOOLS%..\..\VC\vcvarsall.bat" amd64
 #
 # On entry:
 #  1. Args[0] holds the BOOST_ROOT directory.            "c:\boost"
@@ -33,7 +39,7 @@
 #     The version number embedded in the built executables and libraries
 #     comes from qpid/cpp/src/CMakeWinVersions.cmake.
 #  3. Args[2] holds the Visual Studio version handle     "VS2010"
 #     Either VS2008 or VS2010. Defaults to VS2008.
 #  4. Args[3] holds the architecture handle              "x86"
 #     Either x86 or x64. Defaults to x86.
 #  5. This file exists in directory kitroot/qpid/cpp.
@@ -127,6 +133,7 @@ function BuildAPlatform
     [string] $platform_dir  = "$global:currentDirectory/$platform-$vsName"
     [string] $qpid_cpp_src  = "$global:currentDirectory/$qpid_cpp_dir"
     [string] $msvcVer       = ""
+    [string] $msvcVerX      = ""
     
     Write-Host "BuildAPlatform"
     Write-Host " qpid_cpp_dir   : $qpid_cpp_dir"
@@ -143,12 +150,19 @@ function BuildAPlatform
     #
     if ($vsName -eq "VS2008") {
         $msvcVer = "msvc9"
+        $msvcVerX = "msvc9"
     } else {
         if ($vsName -eq "VS2010") {
             $msvcVer = "msvc10"
+            $msvcVerX = "msvcx"
         } else {
-            Write-Host "illegal vsName parameter: $vsName Choose VS2008 or VS2010"
-            exit
+            if ($vsName -eq "VS2012") {
+                $msvcVer = "msvc11"
+                $msvcVerX = "msvcx"
+            } else {
+                Write-Host "illegal vsName parameter: $vsName Choose VS2008, VS2010, or VS2012"
+                exit
+            }
         }
     }
     
@@ -189,7 +203,7 @@ function BuildAPlatform
     devenv qpid-cpp.sln /build "$vsTargetDebug"   /project INSTALL
     devenv qpid-cpp.sln /build "$vsTargetRelease" /project INSTALL
 
-    $bindingSln = Resolve-Path $qpid_cpp_src\bindings\qpid\dotnet\$msvcVer\org.apache.qpid.messaging.sln
+    $bindingSln = Resolve-Path $platform_dir\bindings\qpid\dotnet\$msvcVerX\org.apache.qpid.messaging.sln
     
     # Build the .NET binding
     if ("x86" -eq $platform) {
@@ -304,7 +318,7 @@ function BuildAPlatform
     cmd /c "rd /s /q ""$install_dir/dotnet_examples/examples/msvc10"""
     
     # TODO: Fix up the .NET binding example solution/projects before including them.
-    $src = Resolve-Path "$qpid_cpp_src/bindings/qpid/dotnet/winsdk_sources/$msvcVer"
+    $src = Resolve-Path "$platform_dir/bindings/qpid/dotnet/winsdk_sources/$msvcVerX"
     $dst = Resolve-Path "$install_dir/dotnet_examples"
     Copy-Item "$src\*" -destination "$dst\" -recurse -force
 
@@ -368,8 +382,12 @@ if ( !($global:vsVersion -eq $null) ) {
         if ($global:vsVersion -eq "VS2010") {
             $generator = "Visual Studio 10"
         } else {
-            Write-Host "Visual Studio Version must be VS2008 or VS2010"
-            exit
+            if ($global:vsVersion -eq "VS2012") {
+                $generator = "Visual Studio 11"
+            } else {
+                Write-Host "Visual Studio Version must be VS2008, VS2010, or VS2012"
+                exit
+            }
         }
     }
 } else {



---------------------------------------------------------------------
@@ -33,7 +39,7 @@
 #     comes from qpid/cpp/src/CMakeWinVersions.cmake.
 #  3. Args[2] holds the Visual Studio version handle     "VS2010"
-#     Either VS2008 or VS2010. Defaults to VS2008.
+#     Pick VS2008, VS2010, or VS2012. Defaults to VS2008.
 #  4. Args[3] holds the architecture handle              "x86"
 #     Either x86 or x64. Defaults to x86.
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org